==> OpenCL-0.8.4.tgz: OpenCL-0.8.4/src/get_algo.cpp <==
/*************************************************
* Algorithm Retrieval Source File                *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/lookup.h>

namespace OpenCL {

/*************************************************
* Get a block cipher                             *
*************************************************/
BlockCipher* get_block_cipher(const std::string& name)
   {
   const BlockCipher* cipher = retrieve_block_cipher(name);
   if(cipher)
      return cipher->clone();
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Retrieve a stream cipher                       *
*************************************************/
StreamCipher* get_stream_cipher(const std::string& name)
   {
   const StreamCipher* cipher = retrieve_stream_cipher(name);
   if(cipher)
      return cipher->clone();
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Retrieve a hash function                       *
*************************************************/
HashFunction* get_hash(const std::string& name)
   {
   const HashFunction* hash = retrieve_hash(name);
   if(hash)
      return hash->clone();
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Retrieve a MAC                                 *
*************************************************/
MessageAuthenticationCode* get_mac(const std::string& name)
   {
   const MessageAuthenticationCode* mac = retrieve_mac(name);
   if(mac)
      return mac->clone();
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query the BLOCK_SIZE of a block cipher         *
*************************************************/
u32bit block_size_of(const std::string& name)
   {
   const BlockCipher* cipher = retrieve_block_cipher(name);
   if(cipher)
      return cipher->BLOCK_SIZE;
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query the OUTPUT_LENGTH of a hash or MAC       *
*************************************************/
u32bit output_length_of(const std::string& name)
   {
   const HashFunction* hash = retrieve_hash(name);
   const MessageAuthenticationCode* mac = retrieve_mac(name);

   if(hash && mac)
      throw Internal_Error("output_length_of: multiple lookups on " + name);

   if(hash)
      return hash->OUTPUT_LENGTH;
   if(mac)
      return mac->OUTPUT_LENGTH;

   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query the MINIMUM_KEYLENGTH of an algorithm    *
*************************************************/
u32bit min_keylength_of(const std::string& name)
   {
   const BlockCipher* bc = retrieve_block_cipher(name);
   const StreamCipher* sc = retrieve_stream_cipher(name);
   const MessageAuthenticationCode* mac = retrieve_mac(name);

   if((bc && sc) || (bc && mac) || (sc && mac))
      throw Internal_Error("min_keylength_of: multiple lookups on " + name);

   if(bc)
      return bc->MINIMUM_KEYLENGTH;
   if(sc)
      return sc->MINIMUM_KEYLENGTH;
   if(mac)
      return mac->MINIMUM_KEYLENGTH;

   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query the MAXIMUM_KEYLENGTH of an algorithm    *
*************************************************/
u32bit max_keylength_of(const std::string& name)
   {
   const BlockCipher* bc = retrieve_block_cipher(name);
   const StreamCipher* sc = retrieve_stream_cipher(name);
   const MessageAuthenticationCode* mac = retrieve_mac(name);

   if((bc && sc) || (bc && mac) || (sc && mac))
      throw Internal_Error("max_keylength_of: multiple lookups on " + name);

   if(bc)
      return bc->MAXIMUM_KEYLENGTH;
   if(sc)
      return sc->MAXIMUM_KEYLENGTH;
   if(mac)
      return mac->MAXIMUM_KEYLENGTH;

   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query the KEYLENGTH_MULTIPLE of an algorithm   *
*************************************************/
u32bit keylength_multiple_of(const std::string& name)
   {
   const BlockCipher* bc = retrieve_block_cipher(name);
   const StreamCipher* sc = retrieve_stream_cipher(name);
   const MessageAuthenticationCode* mac = retrieve_mac(name);

   if((bc && sc) || (bc && mac) || (sc && mac))
      throw Internal_Error("keylength_multiple_of: multiple lookups on " +
                           name);

   if(bc)
      return bc->KEYLENGTH_MULTIPLE;
   if(sc)
      return sc->KEYLENGTH_MULTIPLE;
   if(mac)
      return mac->KEYLENGTH_MULTIPLE;

   throw Algorithm_Not_Found(name);
   }

}

==> OpenCL-0.8.5.tgz: OpenCL-0.8.5/src/get_algo.cpp <==
/*************************************************
* Algorithm Retrieval Source File                *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/lookup.h>

namespace OpenCL {

/*************************************************
* Get a block cipher by name                     *
*************************************************/
BlockCipher* get_block_cipher(const std::string& name)
   {
   const BlockCipher* cipher = retrieve_block_cipher(name);
   if(cipher)
      return cipher->clone();
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Get a stream cipher by name                    *
*************************************************/
StreamCipher* get_stream_cipher(const std::string& name)
   {
   const StreamCipher* cipher = retrieve_stream_cipher(name);
   if(cipher)
      return cipher->clone();
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Get a hash function by name                    *
*************************************************/
HashFunction* get_hash(const std::string& name)
   {
   const HashFunction* hash = retrieve_hash(name);
   if(hash)
      return hash->clone();
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Get a MAC by name                              *
*************************************************/
MessageAuthenticationCode* get_mac(const std::string& name)
   {
   const MessageAuthenticationCode* mac = retrieve_mac(name);
   if(mac)
      return mac->clone();
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Get a block cipher padding method by name      *
*************************************************/
const BlockCipherModePaddingMethod* get_bc_pad(const std::string& name)
   {
   const BlockCipherModePaddingMethod* pad = retrieve_bc_pad(name);
   if(pad)
      return pad->clone();
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query if an algorithm exists                   *
*************************************************/
bool have_algorithm(const std::string& name)
   {
   if(retrieve_block_cipher(name))
      return true;
   if(retrieve_stream_cipher(name))
      return true;
   if(retrieve_hash(name))
      return true;
   if(retrieve_mac(name))
      return true;
   return false;
   }

/*************************************************
* Query the BLOCK_SIZE of a block cipher         *
*************************************************/
u32bit block_size_of(const std::string& name)
   {
   const BlockCipher* cipher = retrieve_block_cipher(name);
   if(cipher)
      return cipher->BLOCK_SIZE;
   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query the OUTPUT_LENGTH of a hash or MAC       *
*************************************************/
u32bit output_length_of(const std::string& name)
   {
   const HashFunction* hash = retrieve_hash(name);
   const MessageAuthenticationCode* mac = retrieve_mac(name);

   if(hash && mac)
      throw Internal_Error("output_length_of: multiple lookups on " + name);

   if(hash)
      return hash->OUTPUT_LENGTH;
   if(mac)
      return mac->OUTPUT_LENGTH;

   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query the MINIMUM_KEYLENGTH of an algorithm    *
*************************************************/
u32bit min_keylength_of(const std::string& name)
   {
   const BlockCipher* bc = retrieve_block_cipher(name);
   const StreamCipher* sc = retrieve_stream_cipher(name);
   const MessageAuthenticationCode* mac = retrieve_mac(name);

   if((bc && sc) || (bc && mac) || (sc && mac))
      throw Internal_Error("min_keylength_of: multiple lookups on " + name);

   if(bc)
      return bc->MINIMUM_KEYLENGTH;
   if(sc)
      return sc->MINIMUM_KEYLENGTH;
   if(mac)
      return mac->MINIMUM_KEYLENGTH;

   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query the MAXIMUM_KEYLENGTH of an algorithm    *
*************************************************/
u32bit max_keylength_of(const std::string& name)
   {
   const BlockCipher* bc = retrieve_block_cipher(name);
   const StreamCipher* sc = retrieve_stream_cipher(name);
   const MessageAuthenticationCode* mac = retrieve_mac(name);

   if((bc && sc) || (bc && mac) || (sc && mac))
      throw Internal_Error("max_keylength_of: multiple lookups on " + name);

   if(bc)
      return bc->MAXIMUM_KEYLENGTH;
   if(sc)
      return sc->MAXIMUM_KEYLENGTH;
   if(mac)
      return mac->MAXIMUM_KEYLENGTH;

   throw Algorithm_Not_Found(name);
   }

/*************************************************
* Query the KEYLENGTH_MULTIPLE of an algorithm   *
*************************************************/
u32bit keylength_multiple_of(const std::string& name)
   {
   const BlockCipher* bc = retrieve_block_cipher(name);
   const StreamCipher* sc = retrieve_stream_cipher(name);
   const MessageAuthenticationCode* mac = retrieve_mac(name);

   if((bc && sc) || (bc && mac) || (sc && mac))
      throw Internal_Error("keylength_multiple_of: multiple lookups on " +
                           name);

   if(bc)
      return bc->KEYLENGTH_MULTIPLE;
   if(sc)
      return sc->KEYLENGTH_MULTIPLE;
   if(mac)
      return mac->KEYLENGTH_MULTIPLE;

   throw Algorithm_Not_Found(name);
   }

}
